#!/usr/bin/env python3


# -*- coding: utf-8 -*-


#Creation of the database using Sqlite3 and SQL commands


import sqlite3


conn = sqlite3.connect("../../Results/Db_creation/chia_pet_database.db")
c = conn.cursor()


###########################
# Create table - gin_gene #
###########################
c.execute('''CREATE TABLE IF NOT EXISTS gin_gene
        ([name] VARCHAR(30) NOT NULL,
        [id] INT NOT NULL,
        [chromosome] VARCHAR(2) NOT NULL,
        [start] INT NOT NULL,
        [stop] INT NOT NULL,
        [strand] VARCHAR(1) NOT NULL,
        PRIMARY KEY ([id]))''')


###########################
# Create table - gin_exon #
###########################
c.execute('''CREATE TABLE IF NOT EXISTS gin_exon
        ([id] VARCHAR(30) NOT NULL,
        [pos] INT NOT NULL,
        [name] VARCHAR(45) NOT NULL,
        [id_gene] INT NOT NULL,
        [chromosome] VARCHAR(2) NOT NULL,
        [start] INT NOT NULL,
        [stop] INT NOT NULL,
        [strand] VARCHAR(1) NOT NULL,
        PRIMARY KEY ([id])
        FOREIGN KEY ([id_gene]) REFERENCES gin_gene([id]))''')


##############################
# Create table - gin_project #
##############################
c.execute('''CREATE TABLE IF NOT EXISTS gin_project
        ([id] INT NOT NULL,
        [id_sample] VARCHAR(45) NOT NULL,
        [id_project] VARCHAR(45) NOT NULL,
        [database] VARCHAR(45) NOT NULL,
        [name] VARCHAR(45) NULL,
        [description] TEXT NULL,
        [antiboby] VARCHAR(45) NOT NULL,
        [cell_line] VARCHAR(45) NOT NULL,
        [institute] VARCHAR(45) NULL,
        [citation] VARCHAR(20) NULL,
        PRIMARY KEY ([id]))''')


#####################################
# Create table - gin_gene_frequency #
#####################################
c.execute('''CREATE TABLE IF NOT EXISTS gin_gene_frequency
        ([id] INT NOT NULL,
        [ft] VARCHAR(3) NOT NULL,
        [id_gene] INT NOT NULL,
        [frequency] FLOAT NULL,
        PRIMARY KEY ([id]),
        FOREIGN KEY ([id_gene]) REFERENCES gin_gene([id]))''')


#####################################
# Create table - gin_exon_frequency #
#####################################
c.execute('''CREATE TABLE IF NOT EXISTS gin_exon_frequency
        ([id] INT NOT NULL,
        [ft] VARCHAR(3) NOT NULL,
        [id_exon] VARCHAR(30) NOT NULL,
        [frequency] FLOAT NULL,
        PRIMARY KEY ([id]),
        FOREIGN KEY ([id_exon]) REFERENCES gin_exon([id]))''')


#######################################
# Create table - gin_exon_interaction #
#######################################
c.execute('''CREATE TABLE IF NOT EXISTS gin_exon_interaction
            ([id] INT NOT NULL,
            [force] INT NOT NULL,
            [exon1] VARCHAR(30) NOT NULL,
            [exon2] VARCHAR(30) NOT NULL,
            [id_project] INT NOT NULL,
            [level] VARCHAR(25) NOT NULL,
            PRIMARY KEY ([id]),
            FOREIGN KEY ([exon1]) REFERENCES gin_exon([id]),
            FOREIGN KEY ([exon2]) REFERENCES gin_exon([id]),
            FOREIGN KEY ([id_project]) REFERENCES gin_project([id]))''')


#######################################
# Create table - gin_gene_interaction #
#######################################
c.execute('''CREATE TABLE IF NOT EXISTS gin_gene_interaction
            ([id] INT NOT NULL,
            [force] INT NOT NULL,
            [gene1] INT NOT NULL,
            [gene2] INT NOT NULL,
            [id_project] INT NOT NULL,
            [level] VARCHAR(25) NOT NULL,
            PRIMARY KEY ([id]),
            FOREIGN KEY ([gene1]) REFERENCES gin_gene([id]),
            FOREIGN KEY ([gene2]) REFERENCES gin_gene([id]),
            FOREIGN KEY ([id_project]) REFERENCES gin_project([id]))''')


############################################
# Create table - gin_project_splicing_lore #
############################################
c.execute('''CREATE TABLE IF NOT EXISTS gin_project_splicing_lore
            ([id] INT NOT NULL,
            [project_name] VARCHAR(45) NULL,
            [source_db] VARCHAR(45) NOT NULL,
            [db_id_project] VARCHAR(15) NOT NULL,
            [sf_name] VARCHAR(45) NOT NULL,
            [cl_name] VARCHAR(45) NOT NULL,
            PRIMARY KEY ([id]))''')


############################
# Create table - ase_event #
############################
c.execute('''CREATE TABLE IF NOT EXISTS ase_event
            ([id] INT NOT NULL,
            [id_project] INT NOT NULL,
            [gene_id] INT NOT NULL,
            [pos] INT NOT NULL,
            [exon_id] VARCHAR(30) NOT NULL,
            [delta_psi] FLOAT NULL,
            [pvalue] FLOAT NULL,
            [pvalue_glm_cor] FLOAT NULL,
            PRIMARY KEY ([id]),
            FOREIGN KEY ([exon_id]) REFERENCES gin_exon([id]),
            FOREIGN KEY ([gene_id]) REFERENCES gin_gene([id]),
            FOREIGN KEY ([id_project]) REFERENCES gin_project_splicing_lore([id]))''')

conn.commit()